@@ -1,4 +1,4 @@
-/* Copyright © 2008-2017 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2008-2019 Jakub Wilk <jwilk@jwilk.net>
  *
  * This file is part of pdf2djvu.
  *
@@ -14,14 +14,14 @@
 
 #include "image-filter.hh"
 
-#include <cstddef>
 #include <bitset>
+#include <cassert>
+#include <cstddef>
+#include <cstdint>
 #include <map>
 #include <ostream>
 #include <vector>
 
-#include <stdint.h>
-
 #include "autoconf.hh"
 #include "config.hh"
 #include "djvu-const.hh"
@@ -261,7 +261,7 @@ void DefaultQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *out_bg,
   size_t color_counter = 0;
   std::bitset<1 << 18> original_colors;
   std::bitset<1 << 18> quantized_colors;
-  std::vector<std::vector<Run> > runs(height);
+  std::vector<std::vector<Run>> runs(height);
   for (int i = 0; i < 3; i++)
     background_color[i] = p_bg[i];
   for (int y = 0; y < height; y++)
@@ -489,6 +489,7 @@ void GraphicsMagickQuantizer::operator()(pdf::Renderer *out_fg, pdf::Renderer *o
     image.syncPixels();
   }
   image.quantizeColorSpace(Magick::TransparentColorspace);
+  assert(this->config.fg_colors > 0);
   image.quantizeColors(this->config.fg_colors);
   image.quantize();
   image.colorSpace(Magick::RGBColorspace);
