@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2011-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2011-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -13,18 +13,19 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
+import re
+
 from tools import (
     case,
-    re,
 )
 
 class test(case):
-    # Bug: https://bitbucket.org/jwilk/pdf2djvu/issue/59
-    # + fixed in 0.7.10 [6c155e7cc346]
+    # Bug: https://github.com/jwilk/pdf2djvu/issues/59
+    # + fixed in 0.7.10 [da7cd2524b329a80581b939037f4d42801f3755d]
 
     def test(self):
         self.pdf2djvu('--monochrome').assert_()
         r = self.djvudump()
-        r.assert_(stdout=re(r'Sjbz \[[0-9]{4,}\]'))
+        r.assert_(stdout=re.compile(r'Sjbz \[[0-9]{4,}\]'))
 
 # vim:ts=4 sts=4 sw=4 et
