@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2015-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -13,9 +13,10 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
+import re
+
 from tools import (
     case,
-    re,
 )
 
 class test(case):
@@ -23,14 +24,14 @@ class test(case):
     def test_default(self):
         self.pdf2djvu().assert_()
         r = self.ls()
-        r.assert_(stdout=re(
+        r.assert_(stdout=re.compile(
             r'\n'
             r'\s*1\s+P\s+\d+\s+p0001[.]djvu\s+T=1\n'
             r'\s*2\s+P\s+\d+\s+p0002[.]djvu\s+T=2\n'
         ))
         self.pdf2djvu('--pages', '2').assert_()
         r = self.ls()
-        r.assert_(stdout=re(
+        r.assert_(stdout=re.compile(
             r'\n'
             r'\s*1\s+P\s+\d+\s+p0002[.]djvu\s+T=2\n'
         ))
@@ -39,7 +40,7 @@ class test(case):
         def t(tmpl):
             self.pdf2djvu('--pages', '2', '--page-id-template', tmpl).assert_()
             r = self.ls()
-            r.assert_(stdout=re(
+            r.assert_(stdout=re.compile(
                 r'\n'
                 r'\s*1\s+P\s+\d+\s+p2[.]djvu\sT=2\n'
             ))
@@ -49,7 +50,7 @@ class test(case):
     def test_dpage(self):
         self.pdf2djvu('--pages', '2', '--page-id-template', 'p{dpage}.djvu').assert_()
         r = self.ls()
-        r.assert_(stdout=re(
+        r.assert_(stdout=re.compile(
             r'\n'
             r'\s*1\s+P\s+\d+\s+p1[.]djvu\s+T=2\n'
         ))
@@ -57,7 +58,7 @@ class test(case):
     def test_minus(self):
         self.pdf2djvu('--page-id-template', 'p{page-1}.djvu').assert_()
         r = self.ls()
-        r.assert_(stdout=re(
+        r.assert_(stdout=re.compile(
             r'\n'
             r'\s*1\s+P\s+\d+\s+p0[.]djvu\s+T=1\n'
             r'\s*2\s+P\s+\d+\s+p1[.]djvu\s+T=2\n'
@@ -66,7 +67,7 @@ class test(case):
     def test_plus(self):
         self.pdf2djvu('--page-id-template', 'p{page+7}.djvu').assert_()
         r = self.ls()
-        r.assert_(stdout=re(
+        r.assert_(stdout=re.compile(
             r'\n'
             r'\s*1\s+P\s+\d+\s+p8[.]djvu\s+T=1\n'
             r'\s*2\s+P\s+\d+\s+p9[.]djvu\s+T=2\n'
