@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -13,17 +13,18 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
+import re
+
 from tools import (
     case,
-    re,
 )
 
 class test(case):
-    # + fixed in 0.3.6 [9a9650e7f06f]
+    # + fixed in 0.3.6 [79779eea4fccc83d126ba27408de16a1c5f35d11]
 
     def test(self):
         self.pdf2djvu().assert_()
         r = self.djvudump()
-        r.assert_(stdout=re(r'BG44 \[[0-9][0-9]\] .* 75x75'))
+        r.assert_(stdout=re.compile(r'BG44 \[[0-9][0-9]\] .* 75x75'))
 
 # vim:ts=4 sts=4 sw=4 et
